
# Copyright (c) 2014 Ahmed H. Ismail
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#     http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import
from __future__ import print_function
from __future__ import unicode_literals

import codecs
import os

from spdx.version import Version


def load_license_list(file_name=os.path.join(os.path.dirname(__file__), 'spdx_licenselist.csv')):
    """
    Return a mapping of licenses name->id and id->name loaded from a
    CSV file as "name,identifier"
    """
    licenses_map = {}
    with codecs.open(file_name, 'rb', encoding='utf-8') as licenses:
        for line in licenses:
            name, identifier = line.strip().split(',')
            licenses_map[name] = identifier
            licenses_map[identifier] = name
    return licenses_map


LICENSE_MAP = load_license_list()
LICENSE_LIST_VERSION = Version(major=2, minor=25)
